@@ -160,10 +160,10 @@ def compare(x,y,tol):
     return 0
 
 def almostEqual(x,y,tol):
-    """ Check equality of two iterable objects up to a certain tolerance
+    """ Check equality of two arrays objects up to a certain tolerance
     
     :param x,y: values to be compared
-    :type x,y: iterable objects of floats
+    :type x,y: numpy.ndarray objects of floats
     :param float tol: tolerance to be used
     :return: ``true`` if equal, ``false`` otherwise
     :rtype: bool
@@ -176,7 +176,7 @@ def almostEqual(x,y,tol):
         >>> Misc.almostEqual(np.array([2.]),np.array([2.+2.*eps2]),eps2)
         False
     """
-    return (compare(x,y,tol)==0)
+    return np.all(np.abs(x-y) <= 0.5 * tol * (np.abs(x) + np.abs(y)))
 
 def almostEqualList(xArray,y,tol):
     """ Check equality of a list of floats against an iterable value up to certain tolerance
@@ -205,9 +205,10 @@ def almostEqualList(xArray,y,tol):
         xArray = xArray.reshape((len(xArray),1))
         
     if xArray.shape[1] == len(y):
-        out = np.zeros(xArray.shape[0],dtype=bool)
-        for i in range(xArray.shape[0]):
-            out[i] = (almostEqual(xArray[i,:],y,tol))
+        out = np.all(np.abs(xArray-y[np.newaxis,:]) <= 0.5 * tol * (np.abs(xArray) + np.abs(y)[np.newaxis,:]), axis=1)
+        # out = np.zeros(xArray.shape[0],dtype=bool)
+        # for i in range(xArray.shape[0]):
+        #     out[i] = (almostEqual(xArray[i,:],y,tol))
         return out
     else:
         print "Dimension error!"
