@@ -776,8 +776,8 @@ class Poly1D(object):
             return self.GaussLobattoQuadrature(N,normed,left,right)
         elif quadType == GAUSSRADAU:
             return self.GaussRadauQuadrature(N,normed,end)
-        elif quadType in AVAILQUADPOINTS:
-            if self.poly == HERMITE and (quadType in [GQN,KPN]):
+        elif quadType in AVAIL_QUADPOINTS:
+            if self.poly == HERMITEP_PROB and (quadType in [GQN,KPN]):
                 if quadType == GQN: return gqn(N)
                 if quadType == KPN: return kpn(N)
             if self.poly == JACOBI and (quadType in [GQU,KPU,CC,FEJ]):
@@ -1100,19 +1100,18 @@ class Poly1D(object):
             if (alpha == None):
                 (alpha,) = self.params
             # Recurrence relation
-            old2 = np.ones( (len(r),1) )
+            old2 = np.ones( len(r) )
             if (N == 0):
                 return old2
-            rs = np.reshape(r,(len(r),1))
-            old1 = alpha + 1. - rs
+            old1 = alpha + 1. - r
             if (N == 1):
                 return old1
-            new = ( (3. + alpha - rs) * old1 - (1. + alpha) * old2 ) / 2.0
+            new = ( (3. + alpha - r) * old1 - (1. + alpha) * old2 ) / 2.0
             for i in xrange(3,N+1):
                 n = i - 1.
                 old2 = old1
                 old1 = new
-                new = ( (2*n + alpha + 1. - rs) * old1 - (n + alpha) * old2 ) / (n + 1.)
+                new = ( (2*n + alpha + 1. - r) * old1 - (n + alpha) * old2 ) / (n + 1.)
             return new
     
     def __LaguerreF(self,r,N,alpha=None):
@@ -1415,7 +1414,7 @@ class Poly1D(object):
             if k != 0:
                 print >> self.sdout, "Spectral1D: Error. Derivatives of Polynomials obtained using ORTHPOL package are not implemented"
                 return
-            p = self.__ORTHPOL(r,N)
+            p = self.__ORTHPOL(r,N).flatten()
         
         if (self.poly == JACOBI):
             if not norm:
