@@ -28,7 +28,7 @@
 
 from _version import __version__
 
-__all__ = ["DABISparseGrids", "DABISpectral1D", "DABISpectralND", "DABIStroud", "DABIHeterogeneousSparseGrids", "DABIMisc"]
+__all__ = ["SparseGrids", "Spectral1D", "SpectralND", "Stroud", "HeterogeneousSparseGrids", "Misc"]
 
 __author__ = "Daniele Bigoni"
 __copyright__ = """Copyright 2012-2014, The Technical University of Denmark"""
